@@ -119,7 +119,7 @@ GBLauthors[2] = {
 "- Mandriva package of ISO Master, versions 0.8 - 1.2\n"
 "\n"
 "Matias A. Fonzo\n"
-"- Slackware package of ISO Master, versions 0.8 - 1.2\n"
+"- Slackware package of ISO Master, versions 0.8 - 1.3.1\n"
 "\n"
 "Giovanni Bechis\n"
 "http://www.snb.it/\n"
@@ -149,6 +149,9 @@ NULL};
 
 static const char* 
 GBLtranslators = 
+"Abdellah Chelli\n"
+"- ar (arabic) translation of ISO Master version 1.3\n"
+"\n"
 "Ihar Hrachyshka\n"
 "- be (Belarusian) translation of ISO Master version 1.3\n"
 "\n"
@@ -167,12 +170,24 @@ GBLtranslators =
 "Toni Graffy\n"
 "- de (German) translation of ISO Master versions 0.6 - 1.3\n"
 "\n"
+"Magnus Valle\n"
+"- da (Danish) translation of ISO Master version 1.3\n"
+"\n"
+"Henrik Kristiansen\n"
+"- da (Danish) translation of ISO Master version 1.3\n"
+"\n"
 "Mike Kranidis\n"
 "- el (Greek) translation of ISO Master versions 1.1 - 1.3\n"
 "\n"
 "Juan Garcia-Murga Monago\n"
 "- es (Spanish) translation of ISO Master versions 0.7 - 1.1\n"
 "\n"
+"Leandro Doctors\n"
+"- es (Spanish) translation of ISO Master version 1.3\n"
+"\n"
+"Christobal\n"
+"- es (Spanish) translation of ISO Master version 1.3\n"
+"\n"
 "Edmund Laugasson\n"
 "- et (Estonian) translation of ISO Master version 1.3\n"
 "\n"
@@ -207,7 +222,7 @@ GBLtranslators =
 "- it (Italian) translation of ISO Master version 0.7 - 1.0\n"
 "\n"
 "Valerio Guaglianone\n"
-"- it (Italian) translation of ISO Master version 0.7, 1.1\n"
+"- it (Italian) translation of ISO Master version 0.7, 1.1, 1.6\n"
 "\n"
 "Robert Groenning\n"
 "- nb (Norwegian Bokmal) translation of ISO Master version 1.0\n"
@@ -222,7 +237,13 @@ GBLtranslators =
 "- pl (Polish) translation of ISO Master versions 0.6 - 1.3\n"
 "\n"
 "Joao de Ferro\n"
-"- pt (Portuguese) translation of ISO Master version 0.8, 1.0\n"
+"- pt (Portuguese) translation of ISO Master versions 0.8, 1.0\n"
+"\n"
+"Antonio Sousa\n"
+"- pt (Portuguese) translation of ISO Master version 1.6\n"
+"\n"
+"Alexandre Marques\n"
+"- pt_BR (Portuguese/Brasil) translation of ISO Master version 1.3\n"
 "\n"
 "Bogdan Radulescu\n"
 "- ro (Romanian) translation of ISO Master version 0.7 - 0.8, 1.0\n"
@@ -324,6 +345,9 @@ void showAboutWindowCbk(GtkMenuItem* menuItem, gpointer data)
 #if GTK_MINOR_VERSION >= 6
     gtk_show_about_dialog(GTK_WINDOW(GBLmainWindow), 
                           "name", GBLprogramName,
+#if GTK_MINOR_VERSION >= 12
+                          "program-name", GBLprogramName,
+#endif
                           "authors", GBLauthors,
                           "translator-credits", GBLtranslators,
                           "comments", GBLcomments,
