@@ -12,9 +12,6 @@
 * 
 ******************************************************************************/
 
-#ifdef WIN32
-    #define _CRT_SECURE_NO_WARNINGS 1
-#endif
 #include <stdlib.h>
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -23,8 +20,9 @@
 
 #include "bkInternal.h"
 #include "bkLink.h"
+#include "bkIoWrappers.h"
 
-int addToHardLinkTable(VolInfo* volInfo, off_t position, char* pathAndName, 
+int addToHardLinkTable(VolInfo* volInfo, bk_off_t position, char* pathAndName, 
                        unsigned size, bool onImage, BkHardLink** newLink)
 {
     int rc;
@@ -64,11 +62,11 @@ int addToHardLinkTable(VolInfo* volInfo, off_t position, char* pathAndName,
 
 /* returns 2 if yes 1 if not
 * works even if file1 == file2 */
-int filesAreSame(VolInfo* volInfo, int file1, off_t posFile1, 
-                 int file2, off_t posFile2, unsigned size)
+int filesAreSame(VolInfo* volInfo, int file1, bk_off_t posFile1, 
+                 int file2, bk_off_t posFile2, unsigned size)
 {
-    off_t origPosFile1;
-    off_t origPosFile2;
+    bk_off_t origPosFile1;
+    bk_off_t origPosFile2;
     int numBlocks;
     int sizeLastBlock;
     int count;
@@ -78,8 +76,8 @@ int filesAreSame(VolInfo* volInfo, int file1, off_t posFile1,
     if(size == 0)
         return 2;
     
-    origPosFile1 = lseek(file1, 0, SEEK_CUR);
-    origPosFile2 = lseek(file2, 0, SEEK_CUR);
+    origPosFile1 = bkSeekTell(file1);
+    origPosFile2 = bkSeekTell(file2);
     
     numBlocks = size / READ_WRITE_BUFFER_SIZE;
     sizeLastBlock = size % READ_WRITE_BUFFER_SIZE;
@@ -87,17 +85,17 @@ int filesAreSame(VolInfo* volInfo, int file1, off_t posFile1,
     sameSoFar = true;
     for(count = 0; count < numBlocks; count++)
     {
-        lseek(file1, posFile1, SEEK_SET);
-        rc = read(file1, volInfo->readWriteBuffer, READ_WRITE_BUFFER_SIZE);
+        bkSeekSet(file1, posFile1, SEEK_SET);
+        rc = bkRead(file1, volInfo->readWriteBuffer, READ_WRITE_BUFFER_SIZE);
         if(rc != READ_WRITE_BUFFER_SIZE)
             return BKERROR_READ_GENERIC;
-        posFile1 = lseek(file1, 0, SEEK_CUR);
+        posFile1 = bkSeekTell(file1);
         
-        lseek(file2, posFile2, SEEK_SET);
-        rc = read(file2, volInfo->readWriteBuffer2, READ_WRITE_BUFFER_SIZE);
+        bkSeekSet(file2, posFile2, SEEK_SET);
+        rc = bkRead(file2, volInfo->readWriteBuffer2, READ_WRITE_BUFFER_SIZE);
         if(rc != READ_WRITE_BUFFER_SIZE)
             return BKERROR_READ_GENERIC;
-        posFile2 = lseek(file2, 0, SEEK_CUR);
+        posFile2 = bkSeekTell(file2);
         
         if( memcmp(volInfo->readWriteBuffer, volInfo->readWriteBuffer2, 
             READ_WRITE_BUFFER_SIZE) != 0 )
@@ -109,13 +107,13 @@ int filesAreSame(VolInfo* volInfo, int file1, off_t posFile1,
     
     if(sameSoFar && sizeLastBlock > 0)
     {
-        lseek(file1, posFile1, SEEK_SET);
-        rc = read(file1, volInfo->readWriteBuffer, sizeLastBlock);
+        bkSeekSet(file1, posFile1, SEEK_SET);
+        rc = bkRead(file1, volInfo->readWriteBuffer, sizeLastBlock);
         if(rc != sizeLastBlock)
             return BKERROR_READ_GENERIC;
         
-        lseek(file2, posFile2, SEEK_SET);
-        rc = read(file2, volInfo->readWriteBuffer2, sizeLastBlock);
+        bkSeekSet(file2, posFile2, SEEK_SET);
+        rc = bkRead(file2, volInfo->readWriteBuffer2, sizeLastBlock);
         if(rc != sizeLastBlock)
             return BKERROR_READ_GENERIC;
         
@@ -123,8 +121,8 @@ int filesAreSame(VolInfo* volInfo, int file1, off_t posFile1,
             sameSoFar = false;
     }
     
-    lseek(file1, origPosFile1, SEEK_SET);
-    lseek(file2, origPosFile2, SEEK_SET);
+    bkSeekSet(file1, origPosFile1, SEEK_SET);
+    bkSeekSet(file2, origPosFile2, SEEK_SET);
     
     if(sameSoFar)
         return 2;
@@ -133,7 +131,7 @@ int filesAreSame(VolInfo* volInfo, int file1, off_t posFile1,
 }
 
 /* returns 2 if found 1 if not found */
-int findInHardLinkTable(VolInfo* volInfo, off_t position, 
+int findInHardLinkTable(VolInfo* volInfo, bk_off_t position, 
                         char* pathAndName, unsigned size,
                         bool onImage, BkHardLink** foundLink)
 {
@@ -162,10 +160,10 @@ int findInHardLinkTable(VolInfo* volInfo, off_t position,
             {
                 int origFile;
                 int origFileWasOpened;
-                off_t origFileOffset;
+                bk_off_t origFileOffset;
                 int newFile;
                 bool newFileWasOpened;
-                off_t newFileOffset;
+                bk_off_t newFileOffset;
                 
                 /* set up for reading original file */
                 if(currentLink->onImage)
@@ -196,7 +194,7 @@ int findInHardLinkTable(VolInfo* volInfo, off_t position,
                     if(newFile == -1)
                     {
                         if(origFileWasOpened)
-                            close(origFile);
+                            bkClose(origFile);
                         return BKERROR_OPEN_READ_FAILED;
                     }
                     newFileWasOpened = true;
@@ -207,9 +205,9 @@ int findInHardLinkTable(VolInfo* volInfo, off_t position,
                                   newFile, newFileOffset, size);
                 
                 if(origFileWasOpened)
-                    close(origFile);
+                    bkClose(origFile);
                 if(newFileWasOpened)
-                    close(newFile);
+                    bkClose(newFile);
                 
                 if(rc < 0)
                     return rc;
@@ -228,19 +226,19 @@ int findInHardLinkTable(VolInfo* volInfo, off_t position,
     return 1;
 }
 
-int readFileHead(VolInfo* volInfo, off_t position, char* pathAndName, 
+int readFileHead(VolInfo* volInfo, bk_off_t position, char* pathAndName, 
                  bool onImage, unsigned char* dest, int numBytes)
 {
     int srcFile;
     bool srcFileWasOpened;
-    off_t origPos;
+    bk_off_t origPos;
     int rc;
     
     if(onImage)
     {
         srcFile = volInfo->imageForReading;
-        origPos = lseek(volInfo->imageForReading, 0, SEEK_CUR);
-        lseek(volInfo->imageForReading, position, SEEK_SET);
+        origPos = bkSeekTell(volInfo->imageForReading);
+        bkSeekSet(volInfo->imageForReading, position, SEEK_SET);
         srcFileWasOpened = false;
     }
     else
@@ -251,12 +249,12 @@ int readFileHead(VolInfo* volInfo, off_t position, char* pathAndName,
         srcFileWasOpened = true;
     }
     
-    rc = read(srcFile, dest, numBytes);
+    rc = bkRead(srcFile, dest, numBytes);
     
-    if(!srcFileWasOpened)
-        lseek(volInfo->imageForReading, origPos, SEEK_SET);
+    if(srcFileWasOpened)
+        bkClose(srcFile);
     else
-        close(srcFile);
+        bkSeekSet(volInfo->imageForReading, origPos, SEEK_SET);
     
     if(rc != numBytes)
         return BKERROR_READ_GENERIC;
