@@ -805,15 +805,15 @@ int readFileInfo(VolInfo* volInfo, BkFile* file, int filenameType,
         return BKERROR_READ_GENERIC;
     nameAsOnDisk[lenFileId9660] = '\0';
     
-    /* removeCrapFromFilename(nameAsOnDisk, lenFileId9660); */
+    /* record 9660 name for writing later */
+    strncpy(BK_BASE_PTR(file)->original9660name, nameAsOnDisk, 14);
+    BK_BASE_PTR(file)->original9660name[14] = '\0';
+    
+    removeCrapFromFilename(nameAsOnDisk, lenFileId9660);
     
     strncpy(BK_BASE_PTR(file)->name, nameAsOnDisk, NCHARS_FILE_ID_MAX_STORE - 1);
     BK_BASE_PTR(file)->name[NCHARS_FILE_ID_MAX_STORE - 1] = '\0';
     
-    /* record 9660 name for writing later */
-    strncpy(BK_BASE_PTR(file)->original9660name, BK_BASE_PTR(file)->name, 14);
-    BK_BASE_PTR(file)->original9660name[14] = '\0';
-    
     /* padding field */
     if(lenFileId9660 % 2 == 0)
         readSeekSet(volInfo, 1, SEEK_CUR);
@@ -879,7 +879,7 @@ int readFileInfo(VolInfo* volInfo, BkFile* file, int filenameType,
     {
         BK_BASE_PTR(file)->posixFileMode = volInfo->posixFileDefaults;
     }
-    
+    //~ printf("'%s' %X\n", BK_BASE_PTR(file)->name, BK_BASE_PTR(file)->posixFileMode);
     rc = readRockridgeSymlink(volInfo, (BkSymLink**)specialFile, lenSU);
     if(rc < 0)
         return rc;
@@ -961,6 +961,7 @@ int readPosixFileMode(VolInfo* volInfo, unsigned* posixFileMode, int lenSU)
         
         if(suFields[count] == 'P' && suFields[count + 1] == 'X')
         {
+            //~ printf("%X %X %X %X\n", *(suFields + count + 4), *(suFields + count + 5), *(suFields + count + 6), *(suFields + count + 7));
             read733FromCharArray(suFields + count + 4, posixFileMode);
             
             /* not interested in anything else from this field */
